//  
//  Copyright (C) 2010 Robert Dyer
// 
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
// 
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
// 
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
// 

using System;
using System.Collections.Generic;
using System.Linq;

using Cairo;
using Gdk;
using Gtk;

using Docky.CairoHelper;
using Docky.Services;

namespace Docky.Menus
{
	public class MenuPagingButton : Button
	{
		const int ICON_SIZE = 16;
		const int PADDING = 6;
		
		DockySurface buffer;
		string buttonIcon;
		
		bool IsPrev { get; set; }
		
		public MenuPagingButton (bool isPrev)
		{
			IsPrev = isPrev;
			
			if (IsPrev)
				buttonIcon = "prevpage.svg@" + System.Reflection.Assembly.GetExecutingAssembly ().FullName;
			else
				buttonIcon = "nextpage.svg@" + System.Reflection.Assembly.GetExecutingAssembly ().FullName;
			
			SetSizeRequest (2 * PADDING + ICON_SIZE, -1);
		}
		
		protected override void OnSizeAllocated (Gdk.Rectangle r)
		{
			base.OnSizeAllocated (r);
			ResetBuffer ();
			QueueDraw ();
		}
		
		protected override void OnLeft ()
		{
			base.OnLeft ();
			ResetBuffer ();
			QueueDraw ();
		}
		
		protected override void OnEntered ()
		{
			base.OnEntered ();
			ResetBuffer ();
			QueueDraw ();
		}
		
		protected override bool OnExposeEvent (EventExpose evnt)
		{
			if (!IsRealized)
				return false;
			
			using (Cairo.Context cr = Gdk.CairoHelper.Create (evnt.Window)) {
				if (buffer == null) {
					buffer = new DockySurface (Allocation.Width, Allocation.Height, cr.Target);
					
					using (Gdk.Pixbuf pbuf = DockServices.Drawing.LoadIcon (buttonIcon, ICON_SIZE))
					{
						Gdk.CairoHelper.SetSourcePixbuf (buffer.Context, pbuf,
								(Allocation.Width - pbuf.Width) / 2,
								(Allocation.Height - pbuf.Height) / 2);
						buffer.Context.Paint ();
						
						if (InButton) {
							buffer.Context.Operator = Operator.Add;
							Gdk.CairoHelper.SetSourcePixbuf (buffer.Context, pbuf,
									(Allocation.Width - pbuf.Width) / 2,
									(Allocation.Height - pbuf.Height) / 2);
							buffer.Context.PaintWithAlpha (0.4);
							buffer.Context.Operator = Operator.Over;
						}
					}
				}
				
				buffer.Internal.Show (cr, Allocation.X, Allocation.Y);
			}
			
			return false;
		}
		
		void ResetBuffer ()
		{
			if (buffer != null) {
				buffer.Dispose ();
				buffer = null;
			}
		}
		
		public override void Dispose ()
		{
			ResetBuffer ();
			base.Dispose ();
		}
	}
}
